#!/usr/bin/env python
#
# 
#
# $Header: /opt/cvs/python/packages/share1.5/AutoDockTools/Utilities24/superpose_molecules.py,v 1.1 2009/01/07 18:52:50 rhuey Exp $
#

import os, string
from MolKit import Read




if __name__ == '__main__':
    import sys
    import getopt


    def usage():
        print "Usage: superpose_molecules.py -d datafile"
        print "   Each line in the datafile consists of the filename of a molecule and a list of "
        print "   comma-separated atom numbers. Here is an example: "
        print "       reference.pdb 6110,2448,1938,2470,2493,4619  "
        print "       molecule1.pdb 31,15,1,16,18,20  "
        print "       ...........................     "
        print "   The molecule from first line is used as the reference."
        print "   The molecule listed in each subsequent line is superimposed onto the reference"
        print "   and written to a new file with the new coordinates."
        print "   The number of entries in the comma-separated lists must be the same for each entry (and more than 2) "
        print "        -d    data_filename "
        print "   Optional parameters:"
        print "        [-p]    prefix for new filenames (default 'transposed_')"
        print "        [-v]    verbose output"

    # process command arguments
    try:
        opt_list, args = getopt.getopt(sys.argv[1:], 'd:p:vh')
    except getopt.GetoptError, msg:
        print 'superpose_molecules.py: %s' %msg
        usage()
        sys.exit(2)

    # initialize required parameters
    # optional parameters
    verbose = None
    #-d data_filename
    data_filename = None
    #-p prefix
    prefix = "transposed_"

    #'d:p:vh'
    for o, a in opt_list:
        if o in ('-d', '--d'):
            data_filename = a
            if verbose: print 'set data_filename to ', a
        if o in ('-p', '--p'):
            prefix = a
            if verbose: print 'set prefix to ', a
        if o in ('-v', '--v'):
            verbose = True
            if verbose: print 'set verbose to ', True
        if o in ('-h', '--'):
            usage()
            sys.exit()
    if not data_filename:
        print "superpose_molecules.py: data_filename must be specified."
        usage()
        sys.exit()

    #file specified by data_filename contains filenames + atom indices
    #refilename 0,1,2,3,4,5,6
    #filename1 10,31,22,63,44,51,16
    #filename2 0,1,17,23,24,35,56
    #...
    # NOTE each line has filename and list of indices
    # NOTE the first entry is the reference
    # NOTE THE NUMBER OF INDICES must match,indices must be comma-separated
    #                   (with NO intervening spaces)

    #read the data file
    fptr = open(data_filename)
    lines = fptr.readlines()
    fptr.close()

    #setup the reference molecule
    from MolKit import Read
    from MolKit.molecule import AtomSet
    ref_name, ref_ll = lines[0].split()
    ref_mol = Read(ref_name)[0]
    ref_ats = AtomSet()
    ref_indices = map(int, ref_ll.split(','))
    num_ref_indices = len(ref_indices)
    if num_ref_indices<3: 
        print " At least 3 indices are required! only %d indices found!!!"%(num_ref_indices)
        exit()
    for i in ref_indices:
        #ref_ats.append(ref_mol.allAtoms[i-1])
        ref_ats.append(ref_mol.allAtoms.get(lambda x: x.number==i)[0])

    num_ref_ats = len(ref_ats)

    #setup the tool for the rigid fit
    from mglutil.math.rigidFit import RigidfitBodyAligner
    RFA = RigidfitBodyAligner()
    RFA.setRefCoords(ref_ats.coords)

    #transform the rest of the molecules
    for l in lines[1:]:
        name, ll = l.split() 
        ll.strip()
        moving_mol = Read(name)[0]
        indices = map(int, ll.split(','))
        moving_ats = AtomSet()
        for i in indices: 
            new_atoms = moving_mol.allAtoms.get(lambda x: x.number==i)
            if not len(new_atoms):
                print "There is no atom in %s with number %d" %(name, i)
                break
            else:
                moving_ats.append(new_atoms[0])
            #moving_ats.append(moving_mol.allAtoms.get(lambda x: x.number==i)[0])
        num_moving_ats = len(moving_ats)
        if num_moving_ats!=num_ref_ats:
            print "Number of moving_ats (%d) does not match number of reference atoms (%d). Skipping %s" %(num_moving_ats,num_ref_ats,name)
            continue
        #for i in indices: moving_ats.append(moving_mol.allAtoms[i-1])
        RFA.rigidFit(moving_ats.coords)
        newCoords = RFA.transformCoords(moving_mol.allAtoms.coords)
        if not newCoords is None and newCoords.shape[1]!=3:
            newCoords=newCoords[:,:3]
        outputfilename = prefix + name
        moving_mol.parser.write_with_new_coords(newCoords,outputfilename) 
        if verbose: print 'wrote %s' %outputfilename


# To execute this command type:
# superpose_molecules.py  -d data_filename [-p prefix] -v







#!/usr/bin/env python
#
# 
#
# $Header: /opt/cvs/python/packages/share1.5/AutoDockTools/Utilities24/write_all_complexes.py,v 1.2 2007/10/08 18:14:45 rhuey Exp $
#
# $Id: write_all_complexes.py,v 1.2 2007/10/08 18:14:45 rhuey Exp $
#
import os

from MolKit import Read
from AutoDockTools.Docking import Docking


if __name__ == '__main__':
    import sys
    import getopt


    def usage():
        "Print helpful, accurate usage statement to stdout."
        print "Usage: write_all_complexes.py -d directory"
        print
        print "    Description of command..."
        print "         -d     docking filename"
        print "         -r     receptor filename"
        print "    Optional parameters:"
        print "        [-b]    write complex of best result and receptor only (default is write all)"
        print "        [-o]    output file stem"
        print "        (default is receptorname_ligandname plus '_confnum.pdbqt')"
        print "        [-v]    verbose output"


    # process command arguments
    try:
        opt_list, args = getopt.getopt(sys.argv[1:], 'd:r:bo:vh')
    except getopt.GetoptError, msg:
        print 'write_all_complexes.py: %s' %msg
        usage()
        sys.exit(2)

    # initialize required parameters
    #-d: docking log filename
    docking_filename =  None
    #-r receptor_filename
    receptor_filename = None

    # initialize optional parameter
    #-b print best only
    write_best_only = False
    #-o output_stem
    output_stem = None
    #-v verbose best only
    verbose = False

    #'d:r:bvh'
    for o, a in opt_list:
        #print "o=", o, " a=", a
        if o in ('-d', '--d'):
            docking_filename = a
            if verbose: print 'set docking_filename to ', a
        if o in ('-r', '--r'):
            receptor_filename = a
            if verbose: print 'set receptor_filename to ', a
        if o in ('-b', '--b'):
            write_best_only = True
            if verbose: print 'set write_best_only to ', True
        if o in ('-o', '--o'):
            output_stem = a
            if verbose: print 'set output_stem to ', a
        if o in ('-v', '--v'):
            verbose = True
            if verbose: print 'set verbose to ', True
        if o in ('-h', '--'):
            usage()
            sys.exit()

    if not docking_filename:
        print 'write_all_complexes: docking_filename must be specified.'
        usage()
        sys.exit()

    if not receptor_filename:
        print 'write_all_complexes: receptor_filename must be specified.'
        usage()
        sys.exit()


    d = Docking()
    d.readDlg(docking_filename)
    receptor_stem = os.path.splitext(os.path.basename(receptor_filename))[0]
    print "receptor_stem =", receptor_stem

    rptr = open(receptor_filename)
    receptor_lines = rptr.readlines()
    rptr.close()
    
    if write_best_only:
        if not hasattr(d, 'clusterer'):
            print docking_filename, ' has no clustering... unable to write complex of best result'
            sys.exit()
        rms = d.clusterer.clustering_dict.keys()[0]
        confs = [d.clusterer.clustering_dict[rms][0][0]]
    else:
        confs = d.ch.conformations
        
    if output_stem is None:
        output_stem = receptor_stem + '_' + d.ligMol.name
    for ix, conf in enumerate(confs):
        d.ch.set_conformation(conf)
        if write_best_only:
            ind = 0
        else:
            ind = d.ch.conformations.index(conf)
        ext = '.pdbq'
        if d.version==4.0:
            ext = '.pdbqt'
        outputfilename = output_stem + '_' + str(ix) + ext
        fptr = open(outputfilename, 'w')
        for l in receptor_lines:
            fptr.write(l)
        ctr = 0
        for l in d.ligMol.parser.allLines:
            if l.find("ATOM")==0 or l.find("HETATM")==0:
                crds = d.ligMol.allAtoms[ctr].coords
                rec = "%s%8.3f%8.3f%8.3f%s\n"%(l[:30],crds[0], crds[1], crds[2],l[54:] ) 
                fptr.write(rec)
                ctr += 1
        fptr.close()
        if verbose:
            print "wrote ", outputfilename


# To execute this command type:
# write_all_complexes.py -d docking -r receptor filename 
# optional arguments
# -b write_complex for best docking result only 
# -o output_stem (default is receptorname_ligandname)



#
#
#
#
# $Id: test_prepareLigand.py,v 1.5 2012/09/14 19:01:10 rhuey Exp $
#

import unittest, os, sys
from string import split, find
from MolKit import Read
#import MolKit.molecule
#import MolKit.protein
#MolKit.molecule.bhtreeFlag = 0
#MolKit.protein.bhtreeFlag = 0

class BaseTests(unittest.TestCase):

    def test_default(self):
        """
          l:vo:d:A:CKU:B:R:M
          Required parameter
           [-l]    ligand_filename
          Optional parameters:         defaults vs  options
           -o outputfilename         stem.pdbq     filename
           -d dictionary to write entry listing atom_type list, rbonds and zero_charge atoms list
           -A repair type                  ''      bonds_hydrogens;bonds;hydrogens
           -C do not add charges
           -K add Kollman charges         False      True  
           -U cleanup:merge type(s)    nphs_lps    nphs,lps,'' 
           -B type(s) of rotatable bnds to allow   amide_backbone_guanidinium,
                                                   amide_backbone,amide_guanidinium, 
                                                   backbone_guanidinium, 
                                                   amide, backbone,guanidinium,
                                                   ''
           -B set root                    auto     index 
           -M mode                    automatic    interactive

        """
        cmd = 'set PYTHONPATH=%s'%sys.path[0]
        cmd = cmd + "; ../prepare_ligand.py -l ind.pdb -o test_default.pdbq"
        os.system(cmd)
        fptr = open("test_default.pdbq")
        lines = fptr.readlines()
        fptr.close()
        std_ptr = open("std_ind.pdbq")
        std_lines = std_ptr.readlines()
        std_ptr.close()
        ctr = 0
        for l, std_l in zip(lines, std_lines):
            if find(l, 'REMARK')==-1:
                self.assertEqual(l, std_l)
                ctr+=1



    def test_allow_amide_torsions(self):
        """
        test allow amide torsions
        options
           -B amide
        """
        cmd = 'set PYTHONPATH=%s'%sys.path[0]
        cmd = cmd+"; ../prepare_ligand.py -l ind.pdb -B amide -o test_allow_amide.pdbq"
        os.system(cmd)
        fptr = open("test_allow_amide.pdbq")
        lines = fptr.readlines()
        fptr.close()
        std_ptr = open("std_ind_with_amide.pdbq")
        std_lines = std_ptr.readlines()
        std_ptr.close()
        ctr = 0
        for l, std_l in zip(lines, std_lines):
            if find(l, 'REMARK')==-1:
                self.assertEqual(l, std_l)
                ctr+=1
        #print 'found ', ctr, ' identical output lines'


    def test_set_root_to_5(self):
        """
        test specifying 5th atom as root
        options
           -l 5  set root to 5th atom
        """
        cmd = 'set PYTHONPATH=%s'%sys.path[0]
        cmd = cmd + "; ../prepare_ligand.py -l ind.pdb -R 5 -o test_set_root_to_5.pdbq"
        os.system(cmd)
        fptr = open("test_set_root_to_5.pdbq")
        lines = fptr.readlines()
        fptr.close()
        std_ptr = open("std_ind_setroot_to_5.pdbq")
        std_lines = std_ptr.readlines()
        std_ptr.close()
        ctr = 0
        for l, std_l in zip(lines, std_lines):
            if find(l, 'REMARK')==-1:
                self.assertEqual(l, std_l)
                ctr+=1
        #print 'found ', ctr, ' identical output lines'


    def test_inactivate_all_torsions(self):
        """
        test inactivate_all_torsions 
        options
           -Z 
        """
        cmd = 'set PYTHONPATH=%s'%sys.path[0]
        cmd = cmd+"; ../prepare_ligand.py -l ind.pdb -Z -o test_inactivate_all_torsions.pdbq"
        os.system(cmd)
        fptr = open("test_inactivate_all_torsions.pdbq")
        lines = fptr.readlines()
        fptr.close()
        std_ptr = open("std_ind_inactivate_all_torsions.pdbq")
        std_lines = std_ptr.readlines()
        std_ptr.close()
        ctr = 0
        for l, std_l in zip(lines, std_lines):
            if find(l, 'REMARK')==-1:
                self.assertEqual(l, std_l)
                ctr+=1
        #print 'found ', ctr, ' identical output lines'


    def wtest_setroot_method(self):
        #after autoroot?
        pass


    def wtest_toggle_torsion(self):
        pass

    def wtest_toggle_guanidinium_torsions(self):
        pass

    def wtest_toggle_amide_torsions(self):
        pass

    def wtest_toggle_ppbb_torsions(self):
        pass

    def wtest_toggle_all_torsions(self):
        pass


    def wtest_change_aromatic_criteria(self):
        #use mtx
        pass

    def wtest_limit_torsions(self):
        #use both types
        pass


    def wtest_set_carbon_names(self):
        #????
        pass


    def wtest_write_reference_file(self):
        #same torTree but different coords(?)
        #need to match up atoms....
        pass



class LigandFiles(unittest.TestCase):
    """
    Check 14 ligands in AutoDockTools/Tests/ligandfiles
    """
    def setUp(self):
        self.datadir = "ligandfiles"
        #self.files = [ 'cholesterol.pdb']
        #self.files = [ 'hxw1_rit.pdb']
        #self.files = [ 'pieceCRN.pdb']
        #self.files = [ 'fivPIECE.pdb']
        #self.files = [ 'ld.pdb']
        #self.files = [ 'txp.pdb']
        #self.files = [ 'faicar.pdbq']
        #self.files = [ 'ligandPROB.pdbq']
        #self.files = [ 'lov.pdbq']
        #self.files = [ 'h2.pdbq']
        #self.files = [ 'adenosine.mol2']
        #self.files = [ 'db0000.mol2'] #CHECK HYDROGENS
        #self.files = [ 'mtx.mol2']
        #self.files = [ 'xa.mol2']
        self.files = [ 'cholesterol.pdb', 'hxw1_rit.pdb', 'pieceCRN.pdb',
                       'fivPIECE.pdb', 'ld.pdb', 'txp.pdb', 'faicar.pdbq',
                       'ligandPROB.pdbq', 'lov.pdbq', 'h2.pdbq', 'adenosine.mol2',
                       'db0000.mol2', 'mtx.mol2', 'xa.mol2']
        self.hDict = {}
        self.hDict['cholesterol'] = 0
        self.hDict['hxw1_rit'] = 0
        self.hDict['pieceCRN'] = 1
        self.hDict['fivPIECE'] = 0
        self.hDict['ld'] = 0
        self.hDict['txp'] = 0
        self.hDict['faicar'] = 0
        self.hDict['ligandPROB'] = 0
        self.hDict['lov'] = 0
        self.hDict['h2'] = 0
        self.hDict['adenosine'] = 0
        self.hDict['db0000'] = 0
        self.hDict['mtx'] = 0
        self.hDict['xa'] = 0



    def test_compare_ligand_files(self):
        """
        Test whether the written outputfile contents match stds
        """
        for f in self.files:
            stem = os.path.splitext(f)[0] 
            #print "\n\ntesting ", stem
            inputfilename = os.path.join(self.datadir, f)
            #print "inputfilename=", inputfilename
            outputfilename = "test_pl_" + stem + ".pdbq"
            #print "outputfilename=", outputfilename
            stdfilename = os.path.join(self.datadir, stem +".out.pdbq")
            #print "stdfilename=", stdfilename
            if stem in ['fivPIECE', 'ld']:
                cmd = 'set PYTHONPATH=%s'%sys.path[0]
                cmd = cmd+";../prepare_ligand.py -l " + inputfilename + " -K -o " + outputfilename
            elif stem in ['db0000', 'faicar', 'ligandPROB', 'lov', 'h2', 'adenosine', 'mtx', 'xa']:
                #these already had charges:
                cmd = 'set PYTHONPATH=%s'%sys.path[0]
                cmd = cmd+"; ../prepare_ligand.py -l " + inputfilename + " -C -o " + outputfilename 
                #cmd = "$PYTHONPATH/AutoDockTools/Utilities/prepare_ligand.py -l " + inputfilename + " -C -o " + outputfilename 
            elif stem in ['pieceCRN']:
                cmd = 'set PYTHONPATH=%s'%sys.path[0]
                cmd = cmd+";../prepare_ligand.py -l " + inputfilename + " -K  -o " + outputfilename
            elif self.hDict[stem]:
                cmd = 'set PYTHONPATH=%s'%sys.path[0]
                cmd = cmd+";../prepare_ligand.py -l " + inputfilename + " -A hydrogens -o " + outputfilename
            else:
                cmd = 'set PYTHONPATH=%s'%sys.path[0]
                cmd = cmd+";../prepare_ligand.py -l " + inputfilename + " -o " + outputfilename
            os.system(cmd)
            fptr = open(outputfilename)
            lines = fptr.readlines()
            fptr.close()
            std_ptr = open(stdfilename)
            std_lines = std_ptr.readlines()
            std_ptr.close()
            ctr = 0
            ok = 1
            numatoms = 0
            std_numatoms = 0
            numbranches = 0
            std_numbranches = 0
            ctroot = 0
            numroot = 0
            std_ctroot = 0
            std_numroot = 0
            numaromCs = 0
            std_numaromCs = 0
            match = {}
            match['atoms'] = True
            match['number_tors'] = True
            match['number_branches'] = True
            match['TORSDOF'] = True
            match['root'] = True
            match['tors_atomnames'] = True
            match['aromaticCs'] = True
            for l, std_l in zip(lines, std_lines):
                if find(l, "active torsions")>-1:
                    testnum = int(split(l)[1])
                    stdnum = int(split(std_l)[1])
                    if testnum!=stdnum:
                        #print stem, ' FAILED active torsions'
                        match['number_tors'] = (testnum, stdnum)
                    #self.assertEqual(testnum, stdnum)
                elif find(l, 'REMARK')==-1 and ok:
                    try:
                        self.assertEqual(l, std_l)
                        ctr+=1
                    except:
                        ok = 0
                        print stem, " ERROR: lines did not match "
                        print l, std_l

            for l in lines:
                if find(l, "HETATM")==0 or find(l, "ATOM")==0:
                    numatoms += 1
                    ll = split(l)
                    if ll[1][0]=='A':
                        numaromCs += 1
                elif find(l, "BRANCH")==0:
                    numbranches += 1
                elif find(l, "ROOT")==0:
                    ctroot = 1
                elif find(l, "ENDROOT")==0:
                    ctroot = 0
                elif find(l, "TORSDOF")==0:
                    testTORSDOF = int(split(l)[1])
                    #self.assertEqual(testnum, stdnum)
                if ctroot:
                    numroot += 1


            for std_l in std_lines:
                if find(std_l, "HETATM")==0 or find(std_l, "ATOM")==0:
                    std_numatoms += 1
                    ll = split(std_l)
                    if ll[1][0]=='A':
                        std_numaromCs += 1
                elif find(std_l, "BRANCH")==0:
                    std_numbranches += 1
                elif find(std_l, "ROOT")==0:
                    std_ctroot = 1
                elif find(std_l, "ENDROOT")==0:
                    std_ctroot = 0
                elif find(std_l, "TORSDOF")==0:
                    stdTORSDOF = int(split(std_l)[1])
                    if testTORSDOF!=stdTORSDOF:
                        match['TORSDOF'] = (testTORSDOF, stdTORSDOF)
                if std_ctroot:
                    std_numroot += 1

            if numatoms!=std_numatoms:
                #print stem, ' FAILED numatoms'
                match['atoms'] = ( numatoms, std_numatoms)
            #self.assertEqual(numatoms, std_numatoms) 
            if numbranches!=std_numbranches:
                #print stem, ' FAILED numbranches'
                match['number_branches'] = ( numbranches, std_numbranches)
            #self.assertEqual(numbranches, std_numbranches) 
            if numroot!=std_numroot:
                #print stem, ' FAILED numroot'
                match['root'] = ( numroot, std_numroot)
            #self.assertEqual(numroot, std_numroot) 

            #????match['tors_atomnames'] = True
            if numaromCs!=std_numaromCs:
                #print stem, ' FAILED numaromCs'
                match['numaromCs'] = ( numaromCs, std_numaromCs)

            #print stem, ' new vs std:',
            if ok: 
                pass
                #print ' passed'
            else:
                ct = 0
                firstE = 1
                for k, v in match.items():
                    #print k, v
                    if v != True:
                        if firstE:
                            firstE = 0
                            print
                        print "FAILED ", k, ':', v[0], ' - ', v[1]
                        ct += 1
                if ct==0:
                    print " differed in lines only"
            #print 'found ', ctr, ' identical output lines'

    

class LigandMolecules(unittest.TestCase):
    """
    Check 14 ligands built from files in AutoDockTools/Tests/ligandfiles
    """
    def setUp(self):
        self.datadir = "ligandfiles"
        #self.files = [ 'cholesterol.pdb']
        #self.files = [ 'hxw1_rit.pdb']
        #self.files = [ 'pieceCRN.pdb']
        #self.files = [ 'fivPIECE.pdb']
        #self.files = [ 'ld.pdb']
        #self.files = [ 'txp.pdb']
        #self.files = [ 'faicar.pdbq']
        #self.files = [ 'ligandPROB.pdbq']
        #self.files = [ 'lov.pdbq']
        #self.files = [ 'h2.pdbq']
        #self.files = [ 'adenosine.mol2']
        #self.files = [ 'db0000.mol2'] #CHECK HYDROGENS
        #self.files = [ 'mtx.mol2']
        #self.files = [ 'xa.mol2']
        self.files = [ 'cholesterol.pdb', 'hxw1_rit.pdb', 'pieceCRN.pdb',
                       'txp.pdb', 'faicar.pdbq',
                       'lov.pdbq', 'h2.pdbq', 'adenosine.mol2',
                       'db0000.mol2']
        self.hDict = {}
        self.hDict['cholesterol'] = 0
        self.hDict['hxw1_rit'] = 0
        self.hDict['pieceCRN'] = 1
        self.hDict['fivPIECE'] = 0
        self.hDict['ld'] = 0
        self.hDict['txp'] = 0
        self.hDict['faicar'] = 0
        self.hDict['ligandPROB'] = 0
        self.hDict['lov'] = 0
        self.hDict['h2'] = 0
        self.hDict['adenosine'] = 0
        self.hDict['db0000'] = 0
        self.hDict['mtx'] = 0
        self.hDict['xa'] = 0


    def test_ligands(self):
        """
        Test whether the names of atoms in rotatable bonds match stds
        """
        for f in self.files:
            stem = os.path.splitext(f)[0] 
            #print "\n\ntesting ", stem
            inputfilename = os.path.join(self.datadir, f)
            #print "inputfilename=", inputfilename
            outputfilename = "test_pl_" + stem + ".pdbq"
            #print "outputfilename=", outputfilename
            stdfilename = os.path.join(self.datadir, stem +".out.pdbq")
            #print "stdfilename=", stdfilename
            if stem in ['fivPIECE', 'ld']:
                cmd = 'set PYTHONPATH=%s'%sys.path[0]
                cmd = cmd+";../prepare_ligand.py -l " + inputfilename + " -K -o " + outputfilename
            elif stem in ['db0000', 'faicar', 'ligandPROB', 'lov', 'h2', 'adenosine', 'mtx', 'xa']:
                #these already had charges:
                cmd = 'set PYTHONPATH=%s'%sys.path[0]
                cmd = cmd+";../prepare_ligand.py -l " + inputfilename + " -C -o " + outputfilename 
            elif stem in ['pieceCRN']:
                cmd = 'set PYTHONPATH=%s'%sys.path[0]
                cmd = cmd+";../prepare_ligand.py -l " + inputfilename + " -K  -o " + outputfilename
            elif self.hDict[stem]:
                cmd = 'set PYTHONPATH=%s'%sys.path[0]
                cmd = cmd+";../prepare_ligand.py -l " + inputfilename + " -o " + outputfilename
            else:
                cmd = 'set PYTHONPATH=%s'%sys.path[0]
                cmd = cmd+";../prepare_ligand.py -l " + inputfilename + " -o " + outputfilename
            os.system(cmd)
            lig = Read(outputfilename)[0]
            std_lig = Read(stdfilename)[0]
            #self.assertEqual(len(lig.torTree.torsionMap),len(std_lig.torTree.torsionMap) 
            #self.assertEqual(lig.ROOT.name, std_lig.ROOT.name)
            #check that the names of the atoms in rotatable bnds match
            lig_list = []
            for n in lig.torTree.torsionMap:
                bnd = n.bond
                ats = lig.allAtoms
                lig_list.append((ats[bnd[0]].name, ats[bnd[1]].name))
            for n in std_lig.torTree.torsionMap:
                bnd = n.bond
                std_ats = std_lig.allAtoms
                std_names = (std_ats[bnd[0]].name, std_ats[bnd[1]].name)
                #print "std_names=", std_names
                rev_std_names = (std_ats[bnd[1]].name, std_ats[bnd[0]].name)
                #print "rev_std_names=", rev_std_names
                #self.assertEqual( (std_names in lig_list or rev_std_names in lig_list), True)
            del lig
            del std_lig




if __name__ == '__main__':
    test_cases = [
        'BaseTests',
        'LigandFiles',
        ]
    
    unittest.main( argv=([__name__ ,] + test_cases) )
    #unittest.main()




########################################################################
#
#    Vision Macro - Python source code - file generated by vision
#    Wednesday 08 September 2010 12:11:39 
#    
#       The Scripps Research Institute (TSRI)
#       Molecular Graphics Lab
#       La Jolla, CA 92037, USA
#
# Copyright: Daniel Stoffler, Michel Sanner and TSRI
#   
# revision: Guillaume Vareille
#  
#########################################################################
#
# $Header: /opt/cvs/python/packages/share1.5/AutoDockTools/VisionInterface/Adt/Macro/AutodockVsCSF.py,v 1.2 2010/09/08 19:38:57 jren Exp $
#
# $Id: AutodockVsCSF.py,v 1.2 2010/09/08 19:38:57 jren Exp $
#

from NetworkEditor.macros import MacroNode
class AutodockVsCSF(MacroNode):
    """
    Runs Autodock Virtual Screening on several remote servers with CSF meta scheduler

    Inputs:
    port 1: LigandDB object containing info about the ligand library
    port 2: autogrid_result object containing info about autogrid results
    port 3: DPF template object
   
    Outputs:
    port 1: string containing URL to autodock virtual screening results
    """

    def __init__(self, constrkw={}, name='AutodockVsCSF', **kw):
        kw['name'] = name
        apply( MacroNode.__init__, (self,), kw)

    def beforeAddingToNetwork(self, net):
        MacroNode.beforeAddingToNetwork(self, net)
        from WebServices.VisionInterface.WSNodes import wslib
        from Vision.StandardNodes import stdlib
        net.getEditor().addLibraryInstance(wslib,"WebServices.VisionInterface.WSNodes", "wslib")
        from WebServices.VisionInterface.WSNodes import addOpalServerAsCategory
        try:
            addOpalServerAsCategory("http://oolitevm.calit2.optiputer.net/opal2", replace=False)
        except:
            pass
        try:
            addOpalServerAsCategory("http://kryptonite.nbcr.net/opal2", replace=False)
        except:
            pass

    def afterAddingToNetwork(self):
        masterNet = self.macroNetwork
        from NetworkEditor.macros import MacroNode
        MacroNode.afterAddingToNetwork(self)
        from WebServices.VisionInterface.WSNodes import wslib
        from Vision.StandardNodes import stdlib
        ## building macro network ##
        AutodockVsCSF_0 = self
        from traceback import print_exc
        from WebServices.VisionInterface.WSNodes import wslib
        from Vision.StandardNodes import stdlib
        masterNet.getEditor().addLibraryInstance(wslib,"WebServices.VisionInterface.WSNodes", "wslib")
        from WebServices.VisionInterface.WSNodes import addOpalServerAsCategory
        try:
            addOpalServerAsCategory("http://oolitevm.calit2.optiputer.net/opal2", replace=False)
        except:
            pass
        try:
            addOpalServerAsCategory("http://kryptonite.nbcr.net/opal2", replace=False)
        except:
            pass
        try:
            ## saving node input Ports ##
            input_Ports_1 = self.macroNetwork.ipNode
            apply(input_Ports_1.configure, (), {'paramPanelImmediate': 1, 'expanded': False})
        except:
            print "WARNING: failed to restore MacroInputNode named input Ports in network self.macroNetwork"
            print_exc()
            input_Ports_1=None

        try:
            ## saving node output Ports ##
            output_Ports_2 = self.macroNetwork.opNode
            apply(output_Ports_2.configure, (), {'paramPanelImmediate': 1, 'expanded': False})
            output_Ports_2.move(183, 363)
        except:
            print "WARNING: failed to restore MacroOutputNode named output Ports in network self.macroNetwork"
            print_exc()
            output_Ports_2=None

        try:
            ## saving node PrepareADVSInputs ##
            from Vision.StandardNodes import Generic
            PrepareADVSInputs_3 = Generic(constrkw={}, name='PrepareADVSInputs', library=stdlib)
            self.macroNetwork.addNode(PrepareADVSInputs_3,217,76)
            apply(PrepareADVSInputs_3.addInputPort, (), {'singleConnection': True, 'name': 'ligands', 'cast': True, 'datatype': 'LigandDB', 'defaultValue': None, 'required': True, 'height': 8, 'width': 12, 'shape': 'rect', 'color': '#FFCCFF', 'originalDatatype': 'None'})
            apply(PrepareADVSInputs_3.addInputPort, (), {'singleConnection': True, 'name': 'autogrid_results', 'cast': True, 'datatype': 'autogrid_results', 'defaultValue': None, 'required': True, 'height': 8, 'width': 12, 'shape': 'triangle', 'color': '#FF33CC', 'originalDatatype': 'None'})
            apply(PrepareADVSInputs_3.addInputPort, (), {'singleConnection': True, 'name': 'dpf_template_obj', 'cast': True, 'datatype': 'dpf_template', 'defaultValue': None, 'required': True, 'height': 8, 'width': 12, 'shape': 'triangle', 'color': '#9933FF', 'originalDatatype': 'None'})
            apply(PrepareADVSInputs_3.addOutputPort, (), {'name': 'filter_file', 'datatype': 'string', 'height': 8, 'width': 12, 'shape': 'oval', 'color': 'white'})
            apply(PrepareADVSInputs_3.addOutputPort, (), {'name': 'ligand_lib', 'datatype': 'string', 'height': 8, 'width': 12, 'shape': 'oval', 'color': 'white'})
            apply(PrepareADVSInputs_3.addOutputPort, (), {'name': 'dpf_template_file', 'datatype': 'string', 'height': 8, 'width': 12, 'shape': 'oval', 'color': 'white'})
            apply(PrepareADVSInputs_3.addOutputPort, (), {'name': 'autogrid_res_url', 'datatype': 'string', 'height': 8, 'width': 12, 'shape': 'oval', 'color': 'white'})
            apply(PrepareADVSInputs_3.addOutputPort, (), {'name': 'autogrid_res_local', 'datatype': 'string', 'height': 8, 'width': 12, 'shape': 'oval', 'color': 'white'})
            code = """def doit(self, ligands, autogrid_results, dpf_template_obj):
        dpf = dpf_template_obj.fullpath

        if not(os.path.exists(dpf)):
            print "ERROR: DPF template " + dpf + " does not exist!"
            return '''stop'''
    
        filter_file = ligands.filter_file
        
        if autogrid_results.type == '''url''':
            autogrid_result_url = autogrid_results.path
            autogrid_result_local = ""
        else:
            autogrid_result_url = ""
            autogrid_result_local = autogrid_results.path
        
        ligand_lib = ligands.loc
        
	pass

        self.outputData(filter_file=filter_file, ligand_lib=ligand_lib, dpf_template_file=dpf, autogrid_res_url=autogrid_result_url, autogrid_res_local=autogrid_result_local)

## to ouput data on port filter_file use
## self.outputData(filter_file=data)
## to ouput data on port ligand_lib use
## self.outputData(ligand_lib=data)
## to ouput data on port dpf_template_file use
## self.outputData(dpf_template_file=data)
## to ouput data on port autogrid_res_url use
## self.outputData(autogrid_res_url=data)
## to ouput data on port autogrid_res_local use
## self.outputData(autogrid_res_local=data)









"""
            PrepareADVSInputs_3.configure(function=code)
            apply(PrepareADVSInputs_3.configure, (), {'paramPanelImmediate': 1, 'expanded': False})
        except:
            print "WARNING: failed to restore Generic named PrepareADVSInputs in network self.macroNetwork"
            print_exc()
            PrepareADVSInputs_3=None

        try:
            ## saving node autodock_kryptonite_nbcr_net ##
            from NetworkEditor.items import FunctionNode
            autodock_kryptonite_nbcr_net_4 = FunctionNode(functionOrString='autodock_kryptonite_nbcr_net', host="http://kryptonite.nbcr.net/opal2", namedArgs={'ga_run': '', 'lib': '', 'filter_file_url': '', 'ga_num_evals': '', 'filter_file': '', 'sched': 'SGE', 'urllib': '', 'ga_num_generations': '', 'dpf': '', 'u': '', 'utar': '', 'userlib': '', 'ga_pop_size': '', 'localRun': False, 'email': '', 'execPath': ''}, constrkw={'functionOrString': "'autodock_kryptonite_nbcr_net'", 'host': '"http://kryptonite.nbcr.net/opal2"', 'namedArgs': {'ga_run': '', 'lib': '', 'filter_file_url': '', 'ga_num_evals': '', 'filter_file': '', 'sched': 'SGE', 'urllib': '', 'ga_num_generations': '', 'dpf': '', 'u': '', 'utar': '', 'userlib': '', 'ga_pop_size': '', 'localRun': False, 'email': '', 'execPath': ''}}, name='autodock_kryptonite_nbcr_net', library=wslib)
            self.macroNetwork.addNode(autodock_kryptonite_nbcr_net_4,217,132)
            apply(autodock_kryptonite_nbcr_net_4.inputPortByName['ga_run'].configure, (), {'defaultValue': None})
            apply(autodock_kryptonite_nbcr_net_4.inputPortByName['lib'].configure, (), {'defaultValue': None})
            apply(autodock_kryptonite_nbcr_net_4.inputPortByName['filter_file_url'].configure, (), {'defaultValue': None})
            apply(autodock_kryptonite_nbcr_net_4.inputPortByName['ga_num_evals'].configure, (), {'defaultValue': None})
            apply(autodock_kryptonite_nbcr_net_4.inputPortByName['filter_file'].configure, (), {'defaultValue': None})
            apply(autodock_kryptonite_nbcr_net_4.inputPortByName['sched'].configure, (), {'defaultValue': None})
            apply(autodock_kryptonite_nbcr_net_4.inputPortByName['urllib'].configure, (), {'defaultValue': None})
            apply(autodock_kryptonite_nbcr_net_4.inputPortByName['ga_num_generations'].configure, (), {'defaultValue': None})
            apply(autodock_kryptonite_nbcr_net_4.inputPortByName['dpf'].configure, (), {'defaultValue': None})
            apply(autodock_kryptonite_nbcr_net_4.inputPortByName['u'].configure, (), {'defaultValue': None})
            apply(autodock_kryptonite_nbcr_net_4.inputPortByName['utar'].configure, (), {'defaultValue': None})
            apply(autodock_kryptonite_nbcr_net_4.inputPortByName['userlib'].configure, (), {'defaultValue': None})
            apply(autodock_kryptonite_nbcr_net_4.inputPortByName['ga_pop_size'].configure, (), {'defaultValue': None})
            apply(autodock_kryptonite_nbcr_net_4.inputPortByName['localRun'].configure, (), {'defaultValue': None})
            apply(autodock_kryptonite_nbcr_net_4.inputPortByName['email'].configure, (), {'defaultValue': None})
            apply(autodock_kryptonite_nbcr_net_4.inputPortByName['execPath'].configure, (), {'defaultValue': None})
            autodock_kryptonite_nbcr_net_4.inputPortByName['ga_run'].widget.set(r"", run=False)
            apply(autodock_kryptonite_nbcr_net_4.inputPortByName['lib'].widget.configure, (), {'choices': ('sample', 'NCIDS_SC', 'NCI_DS1', 'NCI_DS2', 'human_metabolome', 'chembridge_building_blocks', 'drugbank_nutraceutics', 'drugbank_smallmol', 'fda_approved')})
            autodock_kryptonite_nbcr_net_4.inputPortByName['lib'].widget.set(r"", run=False)
            autodock_kryptonite_nbcr_net_4.inputPortByName['filter_file_url'].widget.set(r"", run=False)
            autodock_kryptonite_nbcr_net_4.inputPortByName['ga_num_evals'].widget.set(r"", run=False)
            autodock_kryptonite_nbcr_net_4.inputPortByName['filter_file'].rebindWidget()
            autodock_kryptonite_nbcr_net_4.inputPortByName['filter_file'].widget.set(r"", run=False)
            autodock_kryptonite_nbcr_net_4.inputPortByName['filter_file'].unbindWidget()
            apply(autodock_kryptonite_nbcr_net_4.inputPortByName['sched'].widget.configure, (), {'choices': ('SGE', 'CSF')})
            autodock_kryptonite_nbcr_net_4.inputPortByName['sched'].widget.set(r"CSF", run=False)
            autodock_kryptonite_nbcr_net_4.inputPortByName['urllib'].rebindWidget()
            autodock_kryptonite_nbcr_net_4.inputPortByName['urllib'].widget.set(r"", run=False)
            autodock_kryptonite_nbcr_net_4.inputPortByName['urllib'].unbindWidget()
            autodock_kryptonite_nbcr_net_4.inputPortByName['ga_num_generations'].widget.set(r"", run=False)
            autodock_kryptonite_nbcr_net_4.inputPortByName['dpf'].rebindWidget()
            autodock_kryptonite_nbcr_net_4.inputPortByName['dpf'].widget.set(r"", run=False)
            autodock_kryptonite_nbcr_net_4.inputPortByName['dpf'].unbindWidget()
            autodock_kryptonite_nbcr_net_4.inputPortByName['u'].rebindWidget()
            autodock_kryptonite_nbcr_net_4.inputPortByName['u'].widget.set(r"", run=False)
            autodock_kryptonite_nbcr_net_4.inputPortByName['u'].unbindWidget()
            autodock_kryptonite_nbcr_net_4.inputPortByName['utar'].rebindWidget()
            autodock_kryptonite_nbcr_net_4.inputPortByName['utar'].widget.set(r"", run=False)
            autodock_kryptonite_nbcr_net_4.inputPortByName['utar'].unbindWidget()
            autodock_kryptonite_nbcr_net_4.inputPortByName['userlib'].widget.set(r"", run=False)
            autodock_kryptonite_nbcr_net_4.inputPortByName['ga_pop_size'].widget.set(r"", run=False)
            autodock_kryptonite_nbcr_net_4.inputPortByName['localRun'].widget.set(0, run=False)
            autodock_kryptonite_nbcr_net_4.inputPortByName['email'].widget.set(r"", run=False)
            autodock_kryptonite_nbcr_net_4.inputPortByName['execPath'].widget.set(r"", run=False)
            apply(autodock_kryptonite_nbcr_net_4.configure, (), {'paramPanelImmediate': 1, 'expanded': False})
        except:
            print "WARNING: failed to restore FunctionNode named autodock_kryptonite_nbcr_net in network self.macroNetwork"
            print_exc()
            autodock_kryptonite_nbcr_net_4=None

        try:
            ## saving node GetMainURLFromList ##
            from WebServices.VisionInterface.WSNodes import GetMainURLFromListNode
            GetMainURLFromList_5 = GetMainURLFromListNode(constrkw={}, name='GetMainURLFromList', library=wslib)
            self.macroNetwork.addNode(GetMainURLFromList_5,217,188)
            apply(GetMainURLFromList_5.inputPortByName['urls'].configure, (), {'defaultValue': None})
            apply(GetMainURLFromList_5.configure, (), {'paramPanelImmediate': 1, 'expanded': False})
        except:
            print "WARNING: failed to restore GetMainURLFromListNode named GetMainURLFromList in network self.macroNetwork"
            print_exc()
            GetMainURLFromList_5=None

        try:
            ## saving node GetMainURLFromList ##
            from WebServices.VisionInterface.WSNodes import GetMainURLFromListNode
            GetMainURLFromList_7 = GetMainURLFromListNode(constrkw={}, name='GetMainURLFromList', library=wslib)
            self.macroNetwork.addNode(GetMainURLFromList_7,201,301)
            apply(GetMainURLFromList_7.inputPortByName['urls'].configure, (), {'defaultValue': None})
            apply(GetMainURLFromList_7.configure, (), {'paramPanelImmediate': 1, 'expanded': False})
        except:
            print "WARNING: failed to restore GetMainURLFromListNode named GetMainURLFromList in network self.macroNetwork"
            print_exc()
            GetMainURLFromList_7=None

        try:
            ## saving node AutodockSlice_oolitevm_calit2_optiputer_net ##
            from NetworkEditor.items import FunctionNode
            AutodockSlice_oolitevm_calit2_optiputer_net_8 = FunctionNode(functionOrString='AutodockSlice_oolitevm_calit2_optiputer_net', host="http://oolitevm.calit2.optiputer.net/opal2", namedArgs={'execPath': '', 'localRun': False, 'divisor': '', 'lib': '', 'input_url': ''}, constrkw={'functionOrString': "'AutodockSlice_oolitevm_calit2_optiputer_net'", 'host': '"http://oolitevm.calit2.optiputer.net/opal2"', 'namedArgs': {'execPath': '', 'localRun': False, 'divisor': '', 'lib': '', 'input_url': ''}}, name='AutodockSlice_oolitevm_calit2_optiputer_net', library=wslib)
            self.macroNetwork.addNode(AutodockSlice_oolitevm_calit2_optiputer_net_8,200,240)
            apply(AutodockSlice_oolitevm_calit2_optiputer_net_8.inputPortByName['execPath'].configure, (), {'defaultValue': None})
            apply(AutodockSlice_oolitevm_calit2_optiputer_net_8.inputPortByName['localRun'].configure, (), {'defaultValue': None})
            apply(AutodockSlice_oolitevm_calit2_optiputer_net_8.inputPortByName['divisor'].configure, (), {'defaultValue': None})
            apply(AutodockSlice_oolitevm_calit2_optiputer_net_8.inputPortByName['lib'].configure, (), {'defaultValue': None})
            apply(AutodockSlice_oolitevm_calit2_optiputer_net_8.inputPortByName['input_url'].configure, (), {'defaultValue': None})
            AutodockSlice_oolitevm_calit2_optiputer_net_8.inputPortByName['execPath'].widget.set(r"", run=False)
            AutodockSlice_oolitevm_calit2_optiputer_net_8.inputPortByName['localRun'].widget.set(0, run=False)
            AutodockSlice_oolitevm_calit2_optiputer_net_8.inputPortByName['divisor'].widget.set(r"", run=False)
            AutodockSlice_oolitevm_calit2_optiputer_net_8.inputPortByName['lib'].rebindWidget()
            AutodockSlice_oolitevm_calit2_optiputer_net_8.inputPortByName['lib'].widget.set(r"", run=False)
            AutodockSlice_oolitevm_calit2_optiputer_net_8.inputPortByName['lib'].unbindWidget()
            AutodockSlice_oolitevm_calit2_optiputer_net_8.inputPortByName['input_url'].rebindWidget()
            AutodockSlice_oolitevm_calit2_optiputer_net_8.inputPortByName['input_url'].widget.set(r"", run=False)
            AutodockSlice_oolitevm_calit2_optiputer_net_8.inputPortByName['input_url'].unbindWidget()
            apply(AutodockSlice_oolitevm_calit2_optiputer_net_8.configure, (), {'paramPanelImmediate': 1, 'expanded': False})
        except:
            print "WARNING: failed to restore FunctionNode named AutodockSlice_oolitevm_calit2_optiputer_net in network self.macroNetwork"
            print_exc()
            AutodockSlice_oolitevm_calit2_optiputer_net_8=None

        #self.macroNetwork.run()
        self.macroNetwork.freeze()

        ## saving connections for network AutodockVsCSF ##
        if autodock_kryptonite_nbcr_net_4 is not None and GetMainURLFromList_5 is not None:
            try:
                self.macroNetwork.connectNodes(
                    autodock_kryptonite_nbcr_net_4, GetMainURLFromList_5, "result", "urls", blocking=True
                    , splitratio=[0.36974288957131424, 0.63465596053596318])
            except:
                print "WARNING: failed to restore connection between autodock_kryptonite_nbcr_net_4 and GetMainURLFromList_5 in network self.macroNetwork"
        if PrepareADVSInputs_3 is not None and autodock_kryptonite_nbcr_net_4 is not None:
            try:
                self.macroNetwork.connectNodes(
                    PrepareADVSInputs_3, autodock_kryptonite_nbcr_net_4, "filter_file", "filter_file", blocking=True
                    , splitratio=[0.33230642287344903, 0.65770700108889613])
            except:
                print "WARNING: failed to restore connection between PrepareADVSInputs_3 and autodock_kryptonite_nbcr_net_4 in network self.macroNetwork"
        if PrepareADVSInputs_3 is not None and autodock_kryptonite_nbcr_net_4 is not None:
            try:
                self.macroNetwork.connectNodes(
                    PrepareADVSInputs_3, autodock_kryptonite_nbcr_net_4, "ligand_lib", "urllib", blocking=True
                    , splitratio=[0.50680104599665787, 0.51414170500293577])
            except:
                print "WARNING: failed to restore connection between PrepareADVSInputs_3 and autodock_kryptonite_nbcr_net_4 in network self.macroNetwork"
        if PrepareADVSInputs_3 is not None and autodock_kryptonite_nbcr_net_4 is not None:
            try:
                self.macroNetwork.connectNodes(
                    PrepareADVSInputs_3, autodock_kryptonite_nbcr_net_4, "dpf_template_file", "dpf", blocking=True
                    , splitratio=[0.51615646597598808, 0.25661305528484007])
            except:
                print "WARNING: failed to restore connection between PrepareADVSInputs_3 and autodock_kryptonite_nbcr_net_4 in network self.macroNetwork"
        if PrepareADVSInputs_3 is not None and autodock_kryptonite_nbcr_net_4 is not None:
            try:
                self.macroNetwork.connectNodes(
                    PrepareADVSInputs_3, autodock_kryptonite_nbcr_net_4, "autogrid_res_url", "u", blocking=True
                    , splitratio=[0.5760732944947704, 0.2032376887917188])
            except:
                print "WARNING: failed to restore connection between PrepareADVSInputs_3 and autodock_kryptonite_nbcr_net_4 in network self.macroNetwork"
        if PrepareADVSInputs_3 is not None and autodock_kryptonite_nbcr_net_4 is not None:
            try:
                self.macroNetwork.connectNodes(
                    PrepareADVSInputs_3, autodock_kryptonite_nbcr_net_4, "autogrid_res_local", "utar", blocking=True
                    , splitratio=[0.52802808938949819, 0.66978534572736881])
            except:
                print "WARNING: failed to restore connection between PrepareADVSInputs_3 and autodock_kryptonite_nbcr_net_4 in network self.macroNetwork"
        input_Ports_1 = self.macroNetwork.ipNode
        if input_Ports_1 is not None and PrepareADVSInputs_3 is not None:
            try:
                self.macroNetwork.connectNodes(
                    input_Ports_1, PrepareADVSInputs_3, "new", "ligands", blocking=True
                    , splitratio=[0.23314258225660414, 0.72184112037432979])
            except:
                print "WARNING: failed to restore connection between input_Ports_1 and PrepareADVSInputs_3 in network self.macroNetwork"
        if input_Ports_1 is not None and PrepareADVSInputs_3 is not None:
            try:
                self.macroNetwork.connectNodes(
                    input_Ports_1, PrepareADVSInputs_3, "new", "autogrid_results", blocking=True
                    , splitratio=[0.56916626620432731, 0.43089669830392019])
            except:
                print "WARNING: failed to restore connection between input_Ports_1 and PrepareADVSInputs_3 in network self.macroNetwork"
        if input_Ports_1 is not None and PrepareADVSInputs_3 is not None:
            try:
                self.macroNetwork.connectNodes(
                    input_Ports_1, PrepareADVSInputs_3, "new", "dpf_template_obj", blocking=True
                    , splitratio=[0.26502286453989665, 0.3911248444502638])
            except:
                print "WARNING: failed to restore connection between input_Ports_1 and PrepareADVSInputs_3 in network self.macroNetwork"
        output_Ports_2 = self.macroNetwork.opNode
        if GetMainURLFromList_7 is not None and output_Ports_2 is not None:
            try:
                self.macroNetwork.connectNodes(
                    GetMainURLFromList_7, output_Ports_2, "newurl", "new", blocking=True
                    , splitratio=[0.2408747073082603, 0.22897876889044461])
            except:
                print "WARNING: failed to restore connection between GetMainURLFromList_7 and output_Ports_2 in network self.macroNetwork"
        if PrepareADVSInputs_3 is not None and AutodockSlice_oolitevm_calit2_optiputer_net_8 is not None:
            try:
                self.macroNetwork.connectNodes(
                    PrepareADVSInputs_3, AutodockSlice_oolitevm_calit2_optiputer_net_8, "ligand_lib", "lib", blocking=True
                    , splitratio=[0.36439875698533941, 0.58443612376117082])
            except:
                print "WARNING: failed to restore connection between PrepareADVSInputs_3 and AutodockSlice_oolitevm_calit2_optiputer_net_8 in network self.macroNetwork"
        if GetMainURLFromList_5 is not None and AutodockSlice_oolitevm_calit2_optiputer_net_8 is not None:
            try:
                self.macroNetwork.connectNodes(
                    GetMainURLFromList_5, AutodockSlice_oolitevm_calit2_optiputer_net_8, "newurl", "input_url", blocking=True
                    , splitratio=[0.32808833199778697, 0.69237553555389719])
            except:
                print "WARNING: failed to restore connection between GetMainURLFromList_5 and AutodockSlice_oolitevm_calit2_optiputer_net_8 in network self.macroNetwork"
        if AutodockSlice_oolitevm_calit2_optiputer_net_8 is not None and GetMainURLFromList_7 is not None:
            try:
                self.macroNetwork.connectNodes(
                    AutodockSlice_oolitevm_calit2_optiputer_net_8, GetMainURLFromList_7, "result", "urls", blocking=True
                    , splitratio=[0.69930142895840763, 0.2984777644803871])
            except:
                print "WARNING: failed to restore connection between AutodockSlice_oolitevm_calit2_optiputer_net_8 and GetMainURLFromList_7 in network self.macroNetwork"
        self.macroNetwork.runOnNewData.value = True

        ## modifying MacroInputNode dynamic ports
        input_Ports_1 = self.macroNetwork.ipNode
        input_Ports_1.outputPorts[1].configure(name='PrepareADVSInputs_ligands')
        input_Ports_1.outputPorts[2].configure(name='PrepareADVSInputs_autogrid_results')
        input_Ports_1.outputPorts[3].configure(name='PrepareADVSInputs_dpf_template_obj')

        ## modifying MacroOutputNode dynamic ports
        output_Ports_2 = self.macroNetwork.opNode
        output_Ports_2.inputPorts[1].configure(singleConnection='auto')
        output_Ports_2.inputPorts[1].configure(name='GetMainURLFromList_newurl')
        ## configure MacroNode input ports
        AutodockVsCSF_0.inputPorts[0].configure(name='PrepareADVSInputs_ligands')
        AutodockVsCSF_0.inputPorts[0].configure(datatype='LigandDB')
        AutodockVsCSF_0.inputPorts[1].configure(name='PrepareADVSInputs_autogrid_results')
        AutodockVsCSF_0.inputPorts[1].configure(datatype='autogrid_results')
        AutodockVsCSF_0.inputPorts[2].configure(name='PrepareADVSInputs_dpf_template_obj')
        AutodockVsCSF_0.inputPorts[2].configure(datatype='dpf_template')
        ## configure MacroNode output ports
        AutodockVsCSF_0.outputPorts[0].configure(name='GetMainURLFromList_newurl')
        AutodockVsCSF_0.outputPorts[0].configure(datatype='string')

        AutodockVsCSF_0.shrink()

        ## reset modifications ##
        AutodockVsCSF_0.resetTags()
        AutodockVsCSF_0.buildOriginalList()
